export default {
    "index": 16,
    "lineNumber": 2,
    "column": 2,
    "message": "'import' and 'export' may only appear at the top level"
};